@@ -1,6 +1,6 @@
 """
-### Moveread DFY Pipeline
-> Pipeline for Moveread DFY
+### Moveread Pipelines: DFY
+> Full DFY pipeline for Moveread
 """
 import lazy_loader as lazy
 __getattr__, __dir__, __all__ = lazy.attach_stub(__name__, __file__)
\ No newline at end of file
